within MoMoLib.Air.Air_Utilities.Inverses;
function dTofph "Return d and T as a function of p and h"
  extends Modelica.Icons.Function;
  input SI.Pressure p "pressure";
  input SI.SpecificEnthalpy h "specific enthalpy";
  input SI.Pressure delp "iteration accuracy";
  input SI.SpecificEnthalpy delh "iteration accuracy";
  output SI.Density d "density";
  output SI.Temperature T "temperature (K)";

protected
  SI.Temperature Tguess "initial temperature";
  SI.Density dguess "initial density";
  Integer i "iteration counter";
  Real dh "Newton-error in h-direction";
  Real dp "Newton-error in p-direction";
  Real det "determinant of directional derivatives";
  Real deld "Newton-step in d-direction";
  Real delt "Newton-step in T-direction";
  Modelica.Media.Common.HelmholtzDerivs f
    "dimensionless Helmholtz function and dervatives w.r.t. delta and tau";
  Modelica.Media.Common.NewtonDerivatives_ph nDerivs
    "derivatives needed in Newton iteration";
  Boolean found=false "flag for iteration success";

algorithm
  T := 273.15;
  d := p/(Air_Base.Constants.R*T);
  i := 0;

  while ((i < 100) and not found) loop
    f := Basic.Helmholtz(d, T);
    nDerivs := Modelica.Media.Common.Helmholtz_ph(f);
    dh := nDerivs.h - Air_Base.Constants.h_off - h;
    dp := nDerivs.p - p;
    if ((abs(dh) <= delh) and (abs(dp) <= delp)) then
      found := true;
    end if;
    det := nDerivs.ht*nDerivs.pd - nDerivs.pt*nDerivs.hd;
    delt := (nDerivs.pd*dh - nDerivs.hd*dp)/det;
    deld := (nDerivs.ht*dp - nDerivs.pt*dh)/det;
    T := T - delt;
    d := d - deld;
    i := i + 1;
  end while;
end dTofph;
