within MoMoLib.Air.Air_Utilities.Transport;
function eta_dT "Return dynamic viscosity as a function of d and T"
  extends Modelica.Icons.Function;
  input SI.Density d "Density";
  input SI.Temperature T "Temperature";
  output SI.DynamicViscosity eta "Dynamic viscosity";

protected
  Real delta=d/(Air_Base.Constants.MM*Air_Base.Constants.rhored)
    "Reduced density";
  Real tau=Air_Base.Constants.Tred/T "Reciprocal reduced temperature";
  Real Omega "Collision integral";
  SI.DynamicViscosity eta_0=0 "Dilute gas viscosity";
  SI.DynamicViscosity eta_r=0 "Residual fluid viscosity";
  final constant Real[5] b={0.431,-0.4623,0.08406,0.005341,-0.00331};
  final constant Real[5] Nvis={10.72,1.122,0.002019,-8.876,-0.02916};
  final constant Real[5] tvis={0.2,0.05,2.4,0.6,3.6};
  final constant Integer[5] dvis={1,4,9,1,8};
  final constant Integer[5] lvis={0,0,0,1,1};
  final constant Integer[5] gammavis={0,0,0,1,1};

algorithm
  Omega := exp(
    Modelica.Media.Incompressible.TableBased.Polynomials_Temp.evaluate({b[5],b[
    4],b[3],b[2],b[1]}, log(T/103.3)));
  eta_0 := 0.0266958*sqrt(1000*Air_Base.Constants.MM*T)/(0.36^2*Omega);
  for i in 1:5 loop
    eta_r := eta_r + (Nvis[i]*(tau^tvis[i])*(delta^dvis[i])*exp(-gammavis[i]*(
      delta^lvis[i])));
  end for;
  eta := (eta_0 + eta_r)*1E-006;
end eta_dT;
