within MoMoLib.Air.Air_Utilities;
function airBaseProp_pT
  "intermediate property record for air (p and T prefered states)"
  extends Modelica.Icons.Function;
  input Modelica.SIunits.Pressure p "pressure";
  input Modelica.SIunits.Temperature T "temperature";
  output MoMoLib.Common.Properties aux "auxiliary record";
protected
  Modelica.Media.Common.HelmholtzDerivs f
    "dimensionless Helmholtz funcion and dervatives w.r.t. delta and tau";
algorithm
  aux.p := p;
  aux.T := T;
  aux.R := Air_Base.Constants.R;
  (aux.rho) := Inverses.dofpT(
    p=p,
    T=T,
    delp=iter.delp);
  f := Basic.Helmholtz(aux.rho, T);
  aux.h := aux.R*T*(f.tau*f.ftau + f.delta*f.fdelta) - Air_Base.Constants.h_off;
  aux.s := aux.R*(f.tau*f.ftau - f.f) - Air_Base.Constants.s_off;
  aux.pd := aux.R*T*f.delta*(2*f.fdelta + f.delta*f.fdeltadelta);
  aux.pt := aux.R*aux.rho*f.delta*(f.fdelta - f.tau*f.fdeltatau);
  aux.cv := aux.R*(-f.tau*f.tau*f.ftautau);
  aux.cp := aux.cv + aux.T*aux.pt*aux.pt/(aux.rho*aux.rho*aux.pd);
end airBaseProp_pT;
