within MoMoLib;
package Air "Air: Detailed dry air model (130 ... 2000 K)"
extends Modelica.Icons.MaterialPropertiesPackage;
import SI = Modelica.SIunits;

constant Modelica.Media.Interfaces.PartialMedium.FluidConstants airConstants(
  iupacName="Air",
  casRegistryNumber="",
  chemicalFormula="N2, O2, Ar",
  molarMass=28.9586E-003);

constant Modelica.Media.Interfaces.PartialTwoPhaseMedium.FluidConstants
  dryairConstants(
  chemicalFormula="N2, O2, Ar",
  structureFormula="N2, O2, Ar",
  casRegistryNumber="",
  iupacName="air",
  molarMass=0.0289586,
  criticalTemperature=132.5306,
  criticalPressure=3.786e6,
  criticalMolarVolume=0.0845251e-3,
  normalBoilingPoint=78.903,
  meltingPoint=59.75,
  acentricFactor=0.038,
  hasCriticalData=true);


protected
  type MolarHeatCapacity = SI.MolarHeatCapacity (
    min=0,
    max=3.e5,
    nominal=3.e1,
    start=3.e1) "Type for molar heat capacity with medium specific attributes";


  type MolarDensity = Real (
    final quantity="MolarDensity",
    final unit="mol/m3",
    min=0);


  type IsothermalExpansionCoefficient = Real (
    min=0,
    max=1e8,
    unit="1");


annotation (Documentation(info="<html>
<p>
Calculation of fluid properties of air in the fluid region of 130 Kelvin to 2000 Kelvin at pressures up to 2000 MPa. To use this package in your model, select <a href=\"modelica://MoMoLib.Air.Air_dT\">
Air_dT</a>, <a href=\"modelica://MoMoLib.Air.Air_pT\">
Air_pT</a> or <a href=\"modelica://MoMoLib.Air.Air_ph\">Air_ph</a> according to which variables you choose to determine your state.
</p>

<h4>Restriction</h4>
The functions provided by this package shall be used inside of the restricted limits according to the referenced literature.
</p>

<ul>
<li>
<b>p &le; 2000 MPa</b>
</li>
<li>
<b>130 K &le; T &le; 2000 K</i>
</li>
</ul>

<h4>References</h4>
<dl>
<dt>Lemmon, E. W., Jacobsen, R. T., Penoncello, S. G., Friend, D. G.:</dt>
<dd><b>Thermodynamic Properties of Air and Mixtures of Nitrogen, Argon,
and Oxygen From 60 to 2000 K at Pressures to 2000 MPa</b>. J. Phys. Chem. Ref. Data, Vol. 29, No. 3, 2000.
</dd>
<dt>Lemmon, E. W., Jacobsen, R. T.:</dt>
<dd><b>Viscosity and Thermal Conductivity Equations for
Nitrogen, Oxygen, Argon, and Air</b>. International Journal of Thermophysics, Vol. 25, No. 1, January 2004
</dd>
</dl>
</html>"));
end Air;
