within MoMoLib.Interfaces;
partial package PartialRealCondensingGases "Base class for mixtures of real condensing and non-condensing gases"
extends Modelica.Media.Interfaces.PartialMixtureMedium;


  replaceable partial function saturationPressure
  "Return saturation pressure of condensing fluid"
  extends Modelica.Icons.Function;
  input ThermodynamicState state "Thermodynamic state record";
  output AbsolutePressure psat "saturation pressure";
  end saturationPressure;


  replaceable partial function saturationTemperature
  "Return saturation temperature of condensing fluid"
  extends Modelica.Icons.Function;
  input ThermodynamicState state "Thermodynamic state record";
  output Temperature Tsat "saturation temperature";
  end saturationTemperature;


  replaceable partial function massFractionSaturation
  "Return saturation mass fractions"
  extends Modelica.Icons.Function;
  input ThermodynamicState state "Thermodynamic state record";
  output MassFraction[:] Xsat "saturation mass fractions";
  end massFractionSaturation;


  replaceable partial function massFraction_pTphi
  "Return mass fractions as a function of pressure, temperature and relative humidity"
  extends Modelica.Icons.Function;
  input AbsolutePressure p "pressure";
  input Temperature T "temperature";
  input Real phi "relative humidity";
  output MassFraction[:] X "mass fractions";
  end massFraction_pTphi;


  replaceable partial function relativeHumidity "Return relativ humidity"
  extends Modelica.Icons.Function;
  input ThermodynamicState state "Thermodynamic state record";
  output Real phi "relative humidity";
  end relativeHumidity;


  replaceable partial function enthalpyOfVaporization
  "Return vaporization enthalpy of condensing fluid"
  extends Modelica.Icons.Function;
  input ThermodynamicState state "Thermodynamic state record";
  output SpecificEnthalpy r0 "vaporization enthalpy";
  end enthalpyOfVaporization;


  replaceable partial function enthalpyOfLiquid
  "Return liquid enthalpy of condensing fluid"
  extends Modelica.Icons.Function;
  input ThermodynamicState state "Thermodynamic state record";
  output SpecificEnthalpy h "liquid enthalpy";
  end enthalpyOfLiquid;


  replaceable partial function enthalpyOfGas
  "Return enthalpy of non-condensing gas mixture"
  extends Modelica.Icons.Function;
  input ThermodynamicState state "Thermodynamic state record";
  output SpecificEnthalpy h "specific enthalpy";
  end enthalpyOfGas;


  replaceable partial function enthalpyOfCondensingGas
  "Return enthalpy of condensing gas (most often steam)"
  extends Modelica.Icons.Function;
  input ThermodynamicState state "Thermodynamic state record";
  output SpecificEnthalpy h "specific enthalpy";
  end enthalpyOfCondensingGas;


  replaceable partial function enthalpyOfNonCondensingGas
  "Return enthalpy of the non-condensing species"
  extends Modelica.Icons.Function;
  input ThermodynamicState state "Thermodynamic state record";
  output SpecificEnthalpy h "specific enthalpy";
  end enthalpyOfNonCondensingGas;


  replaceable partial function specificEntropy_phX
  "Return specific entropy as a functio of pressure, specific enthalpy and mass fractions"
  extends Modelica.Icons.Function;
  input AbsolutePressure p "Pressure";
  input SpecificEnthalpy h "Specific enthalpy";
  input MassFraction X[:]=reference_X "Mass fractions";
  output SpecificEntropy s "specific entropy";
  algorithm
  s := specificEntropy(setState_phX(
      p,
      h,
      X));
  end specificEntropy_phX;

end PartialRealCondensingGases;
