within MoMoLib.MoistAir.Utilities.IF97_new;
function cond_dT "Thermal conductivity"
  extends Modelica.Icons.Function;
  input SI.Density d "density";
  input SI.Temperature T "temperature (K)";
  output SI.ThermalConductivity lambda "thermal conductivity";
protected
  Integer region(min=1, max=5) "IF97 region, valid values:1,2,3, and 5";
  constant Real n0=1.0 "conductivity coefficient";
  constant Real n1=6.978267 "conductivity coefficient";
  constant Real n2=2.599096 "conductivity coefficient";
  constant Real n3=-0.998254 "conductivity coefficient";
  constant Real[30] nn=array(
      1.3293046,
      1.7018363,
      5.2246158,
      8.7127675,
      -1.8525999,
      -0.40452437,
      -2.2156845,
      -10.124111,
      -9.5000611,
      0.9340469,
      0.2440949,
      1.6511057,
      4.9874687,
      4.3786606,
      0.0,
      0.018660751,
      -0.76736002,
      -0.27297694,
      -0.91783782,
      0.0,
      -0.12961068,
      0.37283344,
      -0.43083393,
      0.0,
      0.0,
      0.044809953,
      -0.1120316,
      0.13333849,
      0.0,
      0.0) "conductivity coefficient";
  constant SI.ThermalConductivity lamstar=0.4945 "scaling conductivity";
  constant SI.Density rhostar=317.763 "scaling density";
  constant SI.Temperature tstar=647.226 "scaling temperature";
  constant SI.Pressure pstar=22.115e6 "scaling pressure";
  constant SI.DynamicViscosity etastar=55.071e-6 "scaling viscosity";
  Integer i "auxiliary variable";
  Integer j "auxiliary variable";
  Real delta "dimensionless density";
  Real tau "dimensionless temperature";
  Real deltam1 "dimensionless density";
  Real taum1 "dimensionless temperature";
  Real Lam0 "part of thermal conductivity";
  Real Lam1 "part of thermal conductivity";
  Real Lam2 "part of thermal conductivity";
  Real tfun "auxiliary variable";
  Real rhofun "auxiliary variable";
  Real dpitau "auxiliary variable";
  Real ddelpi "auxiliary variable";
  Real d2 "auxiliary variable";
  Modelica.Media.Common.GibbsDerivs g
    "dimensionless Gibbs funcion and dervatives w.r.t. pi and tau";
  Modelica.Media.Common.HelmholtzDerivs f
    "dimensionless Helmholtz function and dervatives w.r.t. delta and tau";
  Real Tc=T - 273.15 "Celsius temperature for region check";
  Real Chi "symmetrized compressibility";
  // slightly different variables for industrial use
  constant SI.Density rhostar2=317.7 "Reference density";
  constant SI.Temperature Tstar2=647.25 "Reference temperature";
  constant SI.ThermalConductivity lambdastar=1 "Reference thermal conductivity";
  parameter Real TREL=T/Tstar2 "Relative temperature";
  parameter Real rhoREL=d/rhostar2 "Relative density";
  Real lambdaREL "Relative thermal conductivity";
  Real deltaTREL "Relative temperature increment";
  constant Real[:] C={0.642857,-4.11717,-6.17937,0.00308976,0.0822994,10.0932};
  constant Real[:] dpar={0.0701309,0.0118520,0.00169937,-1.0200};
  constant Real[:] b={-0.397070,0.400302,1.060000};
  constant Real[:] B={-0.171587,2.392190};
  constant Real[:] a={0.0102811,0.0299621,0.0156146,-0.00422464};
  Real Q;
  Real S;
  Real lambdaREL2
    "function, part of the interpolating equation of the thermal conductivity";
  Real lambdaREL1
    "function, part of the interpolating equation of the thermal conductivity";
  Real lambdaREL0
    "function, part of the interpolating equation of the thermal conductivity";
algorithm
  deltaTREL := abs(TREL - 1) + C[4];
  Q := 2 + C[5]/deltaTREL^(3/5);
  if TREL >= 1 then
    S := 1/deltaTREL;
  else
    S := C[6]/deltaTREL^(3/5);
  end if;
  lambdaREL2 := (dpar[1]/TREL^10 + dpar[2])*rhoREL^(9/5)*Modelica.Math.exp(C[1]
    *(1 - rhoREL^(14/5))) + dpar[3]*S*rhoREL^Q*Modelica.Math.exp((Q/(1 + Q))*(1
     - rhoREL^(1 + Q))) + dpar[4]*Modelica.Math.exp(C[2]*TREL^(3/2) + C[3]/
    rhoREL^5);
  lambdaREL1 := b[1] + b[2]*rhoREL + b[3]*Modelica.Math.exp(B[1]*(rhoREL + B[2])
    ^2);
  lambdaREL0 := TREL^(1/2)*sum(a[i]*TREL^(i - 1) for i in 1:4);
  lambdaREL := lambdaREL0 + lambdaREL1 + lambdaREL2;
  lambda := lambdaREL*lambdastar;
end cond_dT;
