within MoMoLib.MoistAir.Utilities.Inverses;
function T_phX
  "Return temperature as a function of pressure, specific enthalpy and mass fractions"
  extends Modelica.Icons.Function;
  input Modelica.SIunits.AbsolutePressure p "Pressure";
  input Modelica.SIunits.SpecificEnthalpy h "specific enthalpy";
  input Modelica.SIunits.MassFraction X[:]=MoMoLib.MoistAir.reference_X
    "Mass fractions";
  output Modelica.SIunits.Temperature T "Temperature";

protected
  MassFraction[nX] Xfull=if size(X, 1) == nX then X else cat(
      1,
      X,
      {1 - sum(X)});

  function T_phX_res
    extends MoMoLib.Common.Numerical.Interfaces.InputFunction;
    input Modelica.SIunits.AbsolutePressure p "Pressure";
    input Modelica.SIunits.SpecificEnthalpy h "specific enthalpy";
    input Modelica.SIunits.MassFraction X[:]=MoMoLib.MoistAir.reference_X
      "Mass fractions";
    output Modelica.SIunits.Temperature T "Temperature";
  algorithm
    y := MoMoLib.MoistAir.Utilities.h_pTX(
        p=p,
        T=x,
        X=X) - h;
  end T_phX_res;

algorithm
  T := MoMoLib.Common.Numerical.RootFinding.BrentMethod(
    function T_phX_res(
      p=p,
      h=h,
      X=Xfull),
    173.15,
    2000,
    1e-9);
  annotation (inverse(h=MoMoLib.MoistAir.Utilities.h_pTX(
          p=p,
          T=T,
          X=X)));
end T_phX;
