within MoMoLib.MoistAir.Utilities.Inverses;
function T_psX
  "Return temperature as function of pressure, specific entropy and mass fractions"
  extends Modelica.Icons.Function;
  input Modelica.SIunits.AbsolutePressure p "Pressure";
  input Modelica.SIunits.SpecificEntropy s "specific entropy";
  input Modelica.SIunits.MassFraction X[:]=MoMoLib.MoistAir.reference_X
    "Mass fractions";
  output Modelica.SIunits.Temperature T "Temperature";

protected
  MassFraction[nX] Xfull=if size(X, 1) == nX then X else cat(
      1,
      X,
      {1 - sum(X)});

  function T_psX_res
    extends MoMoLib.Common.Numerical.Interfaces.InputFunction;
    input Modelica.SIunits.AbsolutePressure p "Pressure";
    input Modelica.SIunits.SpecificEntropy s "specific entropy";
    input Modelica.SIunits.MassFraction X[:]=MoMoLib.MoistAir.reference_X
      "Mass fractions";
    output Modelica.SIunits.Temperature T "Temperature";
  algorithm
    y := MoMoLib.MoistAir.Utilities.s_pTX(
        p=p,
        T=x,
        X=X) - s;
  end T_psX_res;

algorithm
  T := MoMoLib.Common.Numerical.RootFinding.BrentMethod(
    function T_psX_res(
      p=p,
      s=s,
      X=Xfull),
    173.15,
    2000,
    1e-9);
  annotation (inverse(s=MoMoLib.MoistAir.Utilities.s_pTX(
          p=p,
          T=T,
          X=X)));
end T_psX;
