within MoMoLib.MoistAir.Utilities.Transport;
function eta_pTX "Dynamic viscosity"
  extends Modelica.Icons.Function;
  input Modelica.SIunits.AbsolutePressure p "Pressure";
  input Modelica.SIunits.Temperature T "Temperature";
  input Modelica.SIunits.MassFraction X[:]=MoMoLib.MoistAir.reference_X
    "Mass fractions";
  output Modelica.SIunits.DynamicViscosity eta "Dynamic viscosity";

protected
  Real ya;
  Real yd;
  Real yf;
  Real va;
  Real vd;
  Real vf;
  Real xw;
  Real xws;
  Real pd;
  Real pl;
  Real da;
  Real dd;
  Real df;
  Real Omega;
  Real Tred;
  Real etad;
  MoMoLib.MoistAir.Utilities.Transport.coef coef;

algorithm
  xw := X[1]/(1 - X[1]);
  xws := MoMoLib.MoistAir.Utilities.xws_pT(p, T);
  pd := MoMoLib.MoistAir.Utilities.pd_pTX(
    p,
    T,
    X);
  pl := p - pd;
  da := MoMoLib.Air.Air_Utilities.rho_pT(pl, T);
  if ((xw <= xws) or (xws == -1)) then
    if (T < 273.16) then
      dd := pd/(MoMoLib.MoistAir.steam.R*T);
      ya := da/(da + dd);
      yd := 1 - ya;
      Tred := T/coef.epsilon;
      Omega := coef.w[1] + coef.w[2]*Tred + coef.w[3]*Modelica.Math.exp(coef.w[
        4]*Tred)/(coef.w[5] + Tred);
      etad := 2.6695E-006*sqrt(T*coef.M)/(coef.sigma^2*Omega);
      eta := ya*MoMoLib.Air.Air_Utilities.Transport.eta_dT(da, T) + yd*etad;
    else
      dd := MoMoLib.MoistAir.Utilities.IF97_new.rho_pT(pd, T);
      ya := da/(da + dd);
      yd := 1 - ya;
      eta := ya*MoMoLib.Air.Air_Utilities.Transport.eta_dT(da, T) + yd*
        MoMoLib.MoistAir.Utilities.IF97_new.visc_dT(dd, T);
    end if;
  else
    if (T < 273.16) then
      dd := pd/(MoMoLib.MoistAir.steam.R*T);
      ya := da/(da + dd);
      yd := 1 - ya;
      Tred := T/coef.epsilon;
      Omega := coef.w[1] + coef.w[2]*Tred + coef.w[3]*Modelica.Math.exp(coef.w[
        4]*Tred)/(coef.w[5] + Tred);
      etad := 2.6695E-006*sqrt(T*coef.M)/(coef.sigma^2*Omega);
      eta := ya*MoMoLib.Air.Air_Utilities.Transport.eta_dT(da, T) + yd*etad;
    else
      dd := MoMoLib.MoistAir.Utilities.IF97_new.rho_pT(pd, T);
      df := Modelica.Media.Water.IF97_Utilities.rho_pT(p, T);
      yf := (xw - xws)/df/((1 + xws)/(da + dd) + (xw - xws)/df);
      ya := (1 - yf)/(1 + dd/da);
      yd := 1 - (ya + yf);
      eta := ya*MoMoLib.Air.Air_Utilities.Transport.eta_dT(da, T) + yd*
        MoMoLib.MoistAir.Utilities.IF97_new.visc_dT(dd, T) + yf*
        MoMoLib.MoistAir.Utilities.IF97_new.visc_dT(df, T);
    end if;
  end if;
end eta_pTX;
