within MoMoLib.MoistAir.Utilities.Transport;
function lambda_pTX "Thermal conductivity"
  extends Modelica.Icons.Function;
  input Modelica.SIunits.AbsolutePressure p "Pressure";
  input Modelica.SIunits.Temperature T "Temperature";
  input Modelica.SIunits.MassFraction X[:]=MoMoLib.MoistAir.reference_X
    "Mass fractions";
  output Modelica.SIunits.ThermalConductivity lambda "Thermal conductivity";

protected
  Real ya;
  Real yd;
  Real yf;
  Real va;
  Real vd;
  Real vf;
  Real xw;
  Real xws;
  Real pd;
  Real pl;
  Real da;
  Real dd;
  Real df;
  Real Omega;
  Real Tred;
  Real cp;
  Real Eu;
  Real lambdad;
  MoMoLib.MoistAir.Utilities.Transport.coef coef;

algorithm
  xw := X[1]/(1 - X[1]);
  xws := MoMoLib.MoistAir.Utilities.xws_pT(p, T);
  pd := MoMoLib.MoistAir.Utilities.pd_pTX(
    p,
    T,
    X);
  pl := p - pd;
  da := MoMoLib.Air.Air_Utilities.rho_pT(pl, T);
  if ((xw <= xws) or (xws == -1)) then
    if (T < 273.16) then
      dd := pd/(MoMoLib.MoistAir.steam.R*T);
      ya := da/(da + dd);
      yd := 1 - ya;
      Tred := T/coef.epsilon;
      Omega := coef.w[1] + coef.w[2]*Tred + coef.w[3]*Modelica.Math.exp(coef.w[
        4]*Tred)/(coef.w[5] + Tred);
      cp := coef.a[1] + coef.a[2]*T + coef.a[3]*T^2 + coef.a[4]*T^3 + coef.a[5]
        *T^4;
      Eu := 0.35424*cp + 0.1144;
      Eu := 0;
      lambdad := 0.083232*sqrt(T/coef.M)/(coef.sigma^2*Omega)*Eu;
      lambda := ya*MoMoLib.Air.Air_Utilities.Transport.lambda_dT(da, T) + yd*
        lambdad;
    else
      dd := MoMoLib.MoistAir.Utilities.IF97_new.rho_pT(pd, T);
      ya := da/(da + dd);
      yd := 1 - ya;
      lambda := ya*MoMoLib.Air.Air_Utilities.Transport.lambda_dT(da, T) + yd*
        MoMoLib.MoistAir.Utilities.IF97_new.cond_dT(dd, T);
    end if;
  else
    if (T < 273.16) then
      dd := pd/(MoMoLib.MoistAir.steam.R*T);
      df := Water.IAPWS09.Ice09_Utilities.rho_pT(p, T);
      yf := (xw - xws)/df/((1 + xws)/(da + dd) + (xw - xws)/df);
      ya := (1 - yf)/(1 + dd/da);
      yd := 1 - (ya + yf);
      Tred := T/coef.epsilon;
      Omega := coef.w[1] + coef.w[2]*Tred + coef.w[3]*Modelica.Math.exp(coef.w[
        4]*Tred)/(coef.w[5] + Tred);
      cp := coef.a[1] + coef.a[2]*T + coef.a[3]*T^2 + coef.a[4]*T^3 + coef.a[5]
        *T^4;
      Eu := 0.35424*cp + 0.1144;
      lambdad := 0.083232*sqrt(T/coef.M)/(coef.sigma^2*Omega)*Eu;
      lambda := ya*MoMoLib.Air.Air_Utilities.Transport.lambda_dT(da, T) + yd*
        lambdad + yf*2.21;
    else
      dd := MoMoLib.MoistAir.Utilities.IF97_new.rho_pT(pd, T);
      df := Modelica.Media.Water.IF97_Utilities.rho_pT(p, T);
      yf := (xw - xws)/df/((1 + xws)/(da + dd) + (xw - xws)/df);
      ya := (1 - yf)/(1 + dd/da);
      yd := 1 - (ya + yf);
      lambda := ya*MoMoLib.Air.Air_Utilities.Transport.lambda_dT(da, T) + yd*
        MoMoLib.MoistAir.Utilities.IF97_new.cond_dT(dd, T) + yf*
        MoMoLib.MoistAir.Utilities.IF97_new.cond_dT(df, T);
    end if;
  end if;
end lambda_pTX;
