within MoMoLib.MoistAir.Utilities;
function beta_H "Henry's law constant"
  extends Modelica.Icons.Function;

  input Modelica.SIunits.AbsolutePressure p "Pressure";
  input Modelica.SIunits.Temperature T "Temperature";
  output Real beta_H(unit="1/Pa") "Henry's law constant";

protected
  Real[3] A={-9.67578,-9.44833,-8.40954};
  Real[3] B={4.72162,4.43822,4.29587};
  Real[3] C={11.70585,11.42005,10.52779};
  Real[3] psi={0.7812,0.2095,0.0093};

  Real[3] beta=fill(0, 3);
  Real Tr=T/647.096;
  Real tau=1 - Tr;

algorithm
  if ((T < 273.15) or (T > Water.IAPWS95.Water95_Utilities.Basic.Tsat(p))) then
    beta_H := 0;
  else
    for k in 1:3 loop
      beta[k] := Water.IAPWS95.Water95_Utilities.Basic.psat(T)*exp(A[k]/Tr + B[
        k]*tau^(0.355)/Tr + C[k]*Tr^(-0.41)*exp(tau));
    end for;
    beta_H := 1/1.01325*(psi[1]/beta[1] + psi[2]/beta[2] + psi[3]/beta[3]);
  end if;
end beta_H;
