within MoMoLib.MoistAir.Utilities;
function rho_pTX
  "return density as a function of pressure p, temperature T and composition X"
  extends Modelica.Icons.Function;

  input Modelica.SIunits.AbsolutePressure p "Pressure";
  input Modelica.SIunits.Temperature T "Temperature";
  input Modelica.SIunits.MassFraction X[:]=MoMoLib.MoistAir.reference_X
    "Mass fractions";
  output Modelica.SIunits.Density d "Density";

protected
  Real pd;
  Real pl;
  Real xw;
  Real xws;

algorithm
  if (X[1] == 0) then
    d := MoMoLib.Air.Air_Utilities.rho_pT(p, T);
  else
    xw := X[1]/(1 - X[1]);
    xws := Utilities.xws_pT(p, T);
    pd := Utilities.pd_pTX(
      p,
      T,
      X);
    pl := p - pd;
    if ((xw <= xws) or (xws == -1)) then
      if (T < 273.16) then
        d := MoMoLib.Air.Air_Utilities.rho_pT(pl, T) + pd/(MoMoLib.MoistAir.steam.R
          *T);
      else
        d := MoMoLib.Air.Air_Utilities.rho_pT(pl, T) +
          Utilities.IF97_new.rho_pT(pd, T);
      end if;
    else
      if (T < 273.16) then
        d := (1 + xw)/((1 + xws)/(MoMoLib.Air.Air_Utilities.rho_pT(pl, T) + pd/
          (MoMoLib.MoistAir.steam.R*T)) + (xw - xws)/
          Water.IAPWS09.Ice09_Utilities.rho_pT(p, T));
      else
        d := (1 + xw)/((1 + xws)/(MoMoLib.Air.Air_Utilities.rho_pT(pl, T) +
          Utilities.IF97_new.rho_pT(pd, T)) + (xw - xws)/
          Modelica.Media.Water.IF97_Utilities.rho_pT(p, T));
      end if;
    end if;
  end if;
  annotation (Inline=false, LateInline=true);
end rho_pTX;
