within MoMoLib.R134a.R134a_ph;
function dDewDensity_dPressure_der_sat
  "time derivative of vapor density in two-phase region w.r.t pressure"
  extends Modelica.Icons.Function;

  input SaturationProperties sat
    "saturation properties | pressure is used for interpolation";
  input SaturationProperties der_sat "derivative of saturation properties";
  output Real der_ddvdp
    "time derivative of vapor density in two-phase region w.r.t pressure";
protected
  constant Real dv_coef[:,:] = R134aData.dvcoef
    "coefficients of cubic spline for d_vap(p)";
  constant Real p_breaks[:] = R134aData.pbreaks
    "grid points of reduced pressure";
  Integer int "interval number";
  Integer error "interval for spline interpolation not found";
  Real pred "reduced pressure";
  Real localx "oordinate of local spline";
algorithm
  pred := min(sat.psat/R134aData.data.FPCRIT, 1.0);
  (int,error) := Common.FindInterval(pred,
    p_breaks);
  localx := pred - p_breaks[int];
  der_ddvdp := R134aData.data.FDCRIT*
    Common.CubicSplineDerEval(localx, dv_coef[int, 1:4])/R134aData.data.FPCRIT*der_sat.psat;

  annotation ( Documentation(info="<html>
<p>This function calculates the time derivative of vapor density of R134a with regard to the time derivative of p. The non-derivative function is <a href=\"modelica://MoMoLib.R134a.R134a_ph.dewDensity\"> dewDensity</a>.
</p>
<h3> Restrictions</h3>
<p>It is only valid in the two-phase region (i.e., p<sub>triple</sub> &le; p &le; p<sub>crit</sub> ).
</p>
</html>"));
end dDewDensity_dPressure_der_sat;
