within MoMoLib.R134a.R134a_ph;
function dDewEntropy_dPressure
  "derivative of vapor specific entropy in two-phase region w.r.t pressure | use setState_phX function for input"
  extends Modelica.Icons.Function;

  input SaturationProperties sat
    "saturation properties | pressure is used for interpolation";
  output Real dsvdp
    "derivative of vapor specific entropy in two-phase region w.r.t pressure";
protected
  constant Real sv_coef[:,:] = R134aData.svcoef
    "coefficients of cubic spline for s_vap(p)";
  constant Real p_breaks[:] = R134aData.pbreaks
    "grid points of reduced pressure";
  Integer int "interval number";
  Integer error "interval for spline interpolation not found";
  Real pred "reduced pressure";
  Real localx "oordinate of local spline";
algorithm
  pred := min(sat.psat/R134aData.data.FPCRIT, 1.0);
  (int,error) := Common.FindInterval(pred,
    p_breaks);
  localx := pred - p_breaks[int];
  dsvdp := R134aData.data.SCRIT*
    Common.CubicSplineDerEval(localx, sv_coef[int, 1:4])/R134aData.data.FPCRIT;

  annotation ( Documentation(info="<html>
<p>This function calculates the derivative of vapor entropy of R134a with regard to the state variable p (absolute pressure). The non-derivative function is <a href=\"modelica://MoMoLib.R134a.R134a_ph.dewEntropy\"> dewEntropy</a>.
</p>
<h3> Restrictions</h3>
<p>It is only valid in the two-phase region (i.e., p<sub>triple</sub> &le; p &le; p<sub>crit</sub> ).
</p>
</html>"));
end dDewEntropy_dPressure;
