within MoMoLib.R134a.R134a_ph;
function derivsOf_ph
  "derivatives required for inversion of temperature and density functions"

  extends Modelica.Icons.Function;

  input AbsolutePressure p "pressure";
  input SpecificEnthalpy h "specific enthalpy";
  input Integer phase "number of phases";
  output Common.InverseDerivatives_rhoT derivs
    "inverse derivatives for density and temperature";

protected
  Common.HelmholtzDerivs f "helmholtz derivatives";
  SaturationProperties sat "saturation temperature and pressure";
  Common.PhaseBoundaryProperties liq "properties on liquid phase boundary";
  Common.PhaseBoundaryProperties vap "properties on vapor phase boundary";
  Common.NewtonDerivatives_ph newder "newton derivatives";
  Real x "vapor quality";
  Real dxv "1/(v_vap - v_liq)";
algorithm
  derivs.p := p;
  derivs.h := h;
  derivs.phase := getPhase_ph(p, h);

  sat.psat := p;
  sat.Tsat := saturationTemperature(p);

  (derivs.rho,derivs.T) := dt_ph(p=p, h=h);

  if derivs.phase == 2 then
    liq := R134a_liqofdT(T=derivs.T);
    vap := R134a_vapofdT(T=derivs.T);
    x := if liq.h <> vap.h then (h - liq.h)/(vap.h - liq.h) else if h >= vap.h
       then 1 else 0;
    derivs.cv := Common.cv2Phase(
      liq=liq,
      vap=vap,
      x=x,
      p=p,
      T=derivs.T);
    dxv := if (liq.d <> vap.d) then liq.d*vap.d/(liq.d - vap.d) else 0.0;
    derivs.dpT := (vap.s - liq.s)*dxv;
  else
    f := f_R134a(d=derivs.rho, T=derivs.T);
    f.d := derivs.rho;
    f.T := derivs.T;
    f.R := R134aData.R;
    newder := MoMoLib.R134a.Common.Helmholtz_ph(
                                   f=f);
    derivs.cv := -f.R*(f.tau*f.tau*f.ftautau);
    derivs.pd := newder.pd;
    derivs.pt := newder.pt;
    //derivs.dpT := 0;
  end if;

  annotation ( Documentation(info="<html>
<p> This function calculates the derivatives required for an inversion of temperature and density function.
</p>
</html>"));
end derivsOf_ph;
