within MoMoLib.R134a.R134a_ph;
function fid_R134a "helmholtz coefficients of ideal part"
  extends Modelica.Icons.Function;

  input Real delta "reduced density (delta=d/dcrit)";
  input Real tau "reduced temperature (tau=Tcrit/T)";
  output Common.HelmholtzDerivs fid "helmholtz derivatives of ideal part";
protected
  MoMoLib.R134a.R134aData.Ideal id "ideal coeffcients";
  Real atau=abs(tau) "|tau|";
  Real adelta=abs(delta) "|delta|";
algorithm
  fid.f := Modelica.Math.log(adelta) + id.a[1] + id.a[2]*atau + id.a[3]*
    Modelica.Math.log(atau) + id.a[4]*atau^(-0.5) + id.a[5]*atau^(-0.75);
  fid.fdelta := 1.0/adelta;
  fid.fdeltadelta := -1.0/(adelta*adelta);
  fid.ftau := id.a[2] + id.a[3]/atau - 0.5*id.a[4]*atau^(-1.5) - 0.75*id.a[5]
    *atau^(-1.75);
  fid.ftautau := -id.a[3]/(atau*atau) + 0.75*id.a[4]*atau^(-2.5) + 1.3125*id.
    a[5]*atau^(-2.75);
  fid.fdeltatau := 0.0;

  annotation ( Documentation(info="<html>
This function computes the ideal gas helmholtz derivatives of the fundamental equation of Tillner-Roth and Baehr for R134a (1994) w.r.t. to reduced temperature (tau=T_crit/T) and reduced density (delta=rho/rho_crit).
</html>"));
end fid_R134a;
