within MoMoLib.R134a.R134a_ph;
function fres_R134a "calculation of helmholtz derivatives"
  extends Modelica.Icons.Function;

  input Real delta "reduced density (delta=d/dcrit)";
  input Real tau "reduced temperature (tau=Tcrit/T)";
  output Common.HelmholtzDerivs f "helmholtz derivatives";
protected
  MoMoLib.R134a.R134aData.Residual res "residual coefficient";
  Real k "helping var";
  Real dc "helping var";
  Real cdc "helping var";
algorithm
  f.tau := abs(tau);
  f.delta := abs(delta);
  f.f := 0.0;
  f.ftau := 0.0;
  f.fdelta := 0.0;
  f.ftautau := 0.0;
  f.fdeltadelta := 0.0;
  f.fdeltatau := 0.0;
  for i in 1:res.ns1 loop
    k := res.n[i]*f.delta^res.d[i]*f.tau^res.t[i];
    f.f := f.f + k;
    f.fdelta := f.fdelta + k*res.d[i];
    f.fdeltadelta := f.fdeltadelta + k*res.d[i]*(res.d[i] - 1.0);
    f.ftau := f.ftau + k*res.t[i];
    f.ftautau := f.ftautau + k*res.t[i]*(res.t[i] - 1.0);
    f.fdeltatau := f.fdeltatau + k*res.t[i]*res.d[i];
  end for;
  for i in res.ns1 + 1:21 loop
    dc := f.delta^res.c[i];
    cdc := res.c[i]*dc;
    k := Modelica.Math.exp(-dc)*res.n[i]*delta^res.d[i]*f.tau^res.t[i];
    f.f := f.f + k;
    f.fdelta := f.fdelta + k*(res.d[i] - cdc);
    f.fdeltadelta := f.fdeltadelta + k*((res.d[i] - cdc)*(res.d[i] - 1.0 -
      cdc) - res.c[i]*cdc);
    f.ftau := f.ftau + k*res.t[i];
    f.ftautau := f.ftautau + k*res.t[i]*(res.t[i] - 1.0);
    f.fdeltatau := f.fdeltatau + k*res.t[i]*(res.d[i] - cdc);
  end for;
  f.fdelta := f.fdelta/delta;
  f.fdeltadelta := f.fdeltadelta/(delta*delta);
  f.ftau := f.ftau/tau;
  f.ftautau := f.ftautau/(tau*tau);
  f.fdeltatau := f.fdeltatau/(delta*tau);

  annotation ( Documentation(info="<html>
This function computes the residual helmholtz derivatives of the fundamental equation of Tillner-Roth and Baehr for R134a (1994) w.r.t. to reduced temperature (tau=T_crit/T) and reduced density (delta=rho/rho_crit). The function can be used for special properties depending just on the residual derivative parts.
</html>"));
end fres_R134a;
