within MoMoLib.R134a.R134a_ph;
function getPhase_ph "number of phases by pressure and specific enthalpy"
  input AbsolutePressure p "pressure";
  input SpecificEnthalpy h "specific enthalpy";

  output Integer phase "number of phases";

protected
 SaturationProperties sat(psat=p, Tsat=0) "saturation temperature and pressure";
 Modelica.SIunits.SpecificEnthalpy hl=bubbleEnthalpy(sat) "liquid enthalpy";
 Modelica.SIunits.SpecificEnthalpy hv=dewEnthalpy(sat) "vapor enthalpy";

algorithm
phase := if ((h < hl) or (h > hv) or (p > R134aData.data.FPCRIT)) then 1 else 2;

  annotation ( Documentation(info="<html>
This function computes the number of phases for R134a depending on the inputs for absolute pressure and specific enthalpy. It makes use of cubic spline functions for liquid and vapor specific enthalpy.
</html>"));
end getPhase_ph;
