within MoMoLib.R134a.R134a_ph;
function getPhase_ps "number of phases by pressure and entropy"
  input AbsolutePressure p "pressure";
  input SpecificEntropy s "specific entropy";
  output Integer phase "number of phases";

protected
 SaturationProperties sat(psat=p, Tsat=0) "saturation temperature and pressure";
 Modelica.SIunits.SpecificEntropy sl=bubbleEntropy(sat) "liquid entropy";
 Modelica.SIunits.SpecificEntropy sv=dewEntropy(sat) "vapor entropy";

algorithm
phase := if ((s < sl) or (s > sv) or (p > R134aData.data.FPCRIT)) then 1 else 2;

  annotation ( Documentation(info="<html>
This function computes the number of phases for R134a depending on the inputs for absolute pressure and specific entropy. It makes use of cubic spline functions for liquid and vapor specific entropy.
</html>"));
end getPhase_ps;
