within MoMoLib.R134a.R134a_ph;
function hofpsTwoPhase
  "isentropic specific enthalpy in two phase region h(p,s)"
  input AbsolutePressure p "pressure";
  input SpecificEntropy s "specific entropy";
  output SpecificEnthalpy h "specific enthalpy";

protected
  SaturationProperties sat "saturation temperature and pressure";
  Modelica.SIunits.MassFraction x "vapor quality";
  Modelica.SIunits.SpecificEntropy sl "liquid entropy";
  Modelica.SIunits.SpecificEntropy sv "vapor entropy";
  Modelica.SIunits.SpecificEnthalpy hl "liquid enthalpy";
  Modelica.SIunits.SpecificEnthalpy hv "vapor enthalpy";
algorithm
  sat.psat := p;
  // dummy
  sat.Tsat := 0;
  hl := bubbleEnthalpy(sat=sat);
  hv := dewEnthalpy(sat=sat);
  sl := bubbleEntropy(sat=sat);
  sv := dewEntropy(sat=sat);
  x := (s - sl)/(sv - sl);
  h := hl + x*(hv - hl);

  annotation ( Documentation(info="<html>
This function computes the specific enthalpy in two-phase for R134a depending on the inputs for absolute pressure and specific entropy. It makes use of cubic spline functions for liquid and vapor specific enthalpy as well as specific entropy.
</html>"));
end hofpsTwoPhase;
