within MoMoLib.R134a.R134a_ph;
function saturationTemperature_der_p
  "time derivative of saturation temperature in two-phase region"
  extends Modelica.Icons.Function;

  input Modelica.SIunits.AbsolutePressure p "pressure";
  input Real der_p "time derivative of pressure";
  output Real der_Tsat "time derivative of saturation temperature";
protected
  constant Real T_coef[:,:] = R134aData.Tcoef
    "coefficients of cubic spline for Tsat(p)";
  constant Real p_breaks[:] = R134aData.pbreaks
    "grid points of reduced pressure";
  Integer int "interval number";
  Integer error "interval for spline interpolation not found";
  Real pred "reduced pressure";
  Real localx "oordinate of local spline";
algorithm
  pred := p/R134aData.data.FPCRIT;
  (int,error) := Common.FindInterval(pred,
    p_breaks);
  localx := pred - p_breaks[int];
  der_Tsat := Common.CubicSplineDerEval(localx,
    T_coef[int, :])/R134aData.data.FPCRIT*der_p;

  annotation (
    Documentation(info="<html>
<p>This function calculates the time derivative of saturation temperature of R134a with regard to the time derivative of p. The non-derivative function is <a href=\"modelica://MoMoLib.R134a.R134a_ph.saturationTemperature\"> saturatuionTemperature</a>.
</p>
<h3> Restrictions</h3>
<p>It is only valid in the two-phase region (i.e., p<sub>triple</sub> &le; p &le; p<sub>crit</sub> ).
</p>
</html>"));
end saturationTemperature_der_p;
